==> WWW-GoKGS-0.17.tar.gz: WWW-GoKGS-0.17/xt/data/TournEntrants/20140616-id-104-sort-n/expected.pl <==
{
  'entrants' => [
    {
      'name' => 'Go81',
      'notes' => '',
      'position' => 4,
      'rank' => '-',
      'score' => 2
    },
    {
      'name' => 'gonzoBot2',
      'notes' => '',
      'position' => 4,
      'rank' => '-',
      'score' => 2
    },
    {
      'name' => 'IdiotBot',
      'notes' => '',
      'position' => 7,
      'rank' => '30k',
      'score' => 0
    },
    {
      'name' => 'NeuronC',
      'notes' => '',
      'position' => 3,
      'rank' => '20k',
      'score' => 4
    },
    {
      'name' => 'SimpleBot',
      'notes' => '',
      'position' => 4,
      'rank' => '30k',
      'score' => 2
    },
    {
      'name' => 'tlsBotExp1',
      'notes' => 'Winner',
      'position' => 1,
      'rank' => '-',
      'score' => 6
    },
    {
      'name' => 'viking5',
      'notes' => '',
      'position' => 2,
      'rank' => '-',
      'score' => 5
    }
  ],
  'links' => {
    'entrants' => [
      {
        'sort_by' => 'name',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=n&id=104')}, 'URI::http' )
      },
      {
        'sort_by' => 'result',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=s&id=104')}, 'URI::http' )
      }
    ],
    'rounds' => [
      {
        'end_time' => '2005-07-10T16:45Z',
        'round' => 1,
        'start_time' => '2005-07-10T16:10Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=1')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T17:20Z',
        'round' => 2,
        'start_time' => '2005-07-10T16:45Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=2')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T17:55Z',
        'round' => 3,
        'start_time' => '2005-07-10T17:20Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=3')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T18:30Z',
        'round' => 4,
        'start_time' => '2005-07-10T17:55Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=4')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T19:05Z',
        'round' => 5,
        'start_time' => '2005-07-10T18:30Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=5')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T19:40Z',
        'round' => 6,
        'start_time' => '2005-07-10T19:05Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=6')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T20:15Z',
        'round' => 7,
        'start_time' => '2005-07-10T19:40Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=7')}, 'URI::http' )
      }
    ]
  },
  'name' => 'Fourth KGS Computer Go Tournament - Open division',
  'results' => {
    'Go81' => {
      'IdiotBot' => '1/1',
      'NeuronC' => '0/1',
      'SimpleBot' => '0/1',
      'gonzoBot2' => '1/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'IdiotBot' => {
      'Go81' => '0/1',
      'NeuronC' => '0/1',
      'SimpleBot' => '0/1',
      'gonzoBot2' => '0/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'NeuronC' => {
      'Go81' => '1/1',
      'IdiotBot' => '1/1',
      'SimpleBot' => '1/1',
      'gonzoBot2' => '1/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'SimpleBot' => {
      'Go81' => '1/1',
      'IdiotBot' => '1/1',
      'NeuronC' => '0/1',
      'gonzoBot2' => '0/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'gonzoBot2' => {
      'Go81' => '0/1',
      'IdiotBot' => '1/1',
      'NeuronC' => '0/1',
      'SimpleBot' => '1/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'tlsBotExp1' => {
      'Go81' => '1/1',
      'IdiotBot' => '1/1',
      'NeuronC' => '1/1',
      'SimpleBot' => '1/1',
      'gonzoBot2' => '1/1',
      'viking5' => '1/1'
    },
    'viking5' => {
      'Go81' => '1/1',
      'IdiotBot' => '1/1',
      'NeuronC' => '1/1',
      'SimpleBot' => '1/1',
      'gonzoBot2' => '1/1',
      'tlsBotExp1' => '0/1'
    }
  }
}

==> WWW-GoKGS-0.20.tar.gz: WWW-GoKGS-0.20/xt/data/TournEntrants/20140616-id-104-sort-n/expected.pl <==
{
  'entrants' => [
    {
      'name' => 'Go81',
      'notes' => '',
      'position' => 4,
      'rank' => '-',
      'score' => 2
    },
    {
      'name' => 'gonzoBot2',
      'notes' => '',
      'position' => 4,
      'rank' => '-',
      'score' => 2
    },
    {
      'name' => 'IdiotBot',
      'notes' => '',
      'position' => 7,
      'rank' => '30k',
      'score' => 0
    },
    {
      'name' => 'NeuronC',
      'notes' => '',
      'position' => 3,
      'rank' => '20k',
      'score' => 4
    },
    {
      'name' => 'SimpleBot',
      'notes' => '',
      'position' => 4,
      'rank' => '30k',
      'score' => 2
    },
    {
      'name' => 'tlsBotExp1',
      'notes' => 'Winner',
      'position' => 1,
      'rank' => '-',
      'score' => 6
    },
    {
      'name' => 'viking5',
      'notes' => '',
      'position' => 2,
      'rank' => '-',
      'score' => 5
    }
  ],
  'links' => {
    'entrants' => [
      {
        'sort_by' => 'name',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=n&id=104')}, 'URI::http' )
      },
      {
        'sort_by' => 'result',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=s&id=104')}, 'URI::http' )
      }
    ],
    'rounds' => [
      {
        'end_time' => '2005-07-10T16:45',
        'round' => 1,
        'start_time' => '2005-07-10T16:10',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=1')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T17:20',
        'round' => 2,
        'start_time' => '2005-07-10T16:45',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=2')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T17:55',
        'round' => 3,
        'start_time' => '2005-07-10T17:20',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=3')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T18:30',
        'round' => 4,
        'start_time' => '2005-07-10T17:55',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=4')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T19:05',
        'round' => 5,
        'start_time' => '2005-07-10T18:30',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=5')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T19:40',
        'round' => 6,
        'start_time' => '2005-07-10T19:05',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=6')}, 'URI::http' )
      },
      {
        'end_time' => '2005-07-10T20:15',
        'round' => 7,
        'start_time' => '2005-07-10T19:40',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=104&round=7')}, 'URI::http' )
      }
    ]
  },
  'name' => 'Fourth KGS Computer Go Tournament - Open division',
  'results' => {
    'Go81' => {
      'IdiotBot' => '1/1',
      'NeuronC' => '0/1',
      'SimpleBot' => '0/1',
      'gonzoBot2' => '1/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'IdiotBot' => {
      'Go81' => '0/1',
      'NeuronC' => '0/1',
      'SimpleBot' => '0/1',
      'gonzoBot2' => '0/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'NeuronC' => {
      'Go81' => '1/1',
      'IdiotBot' => '1/1',
      'SimpleBot' => '1/1',
      'gonzoBot2' => '1/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'SimpleBot' => {
      'Go81' => '1/1',
      'IdiotBot' => '1/1',
      'NeuronC' => '0/1',
      'gonzoBot2' => '0/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'gonzoBot2' => {
      'Go81' => '0/1',
      'IdiotBot' => '1/1',
      'NeuronC' => '0/1',
      'SimpleBot' => '1/1',
      'tlsBotExp1' => '0/1',
      'viking5' => '0/1'
    },
    'tlsBotExp1' => {
      'Go81' => '1/1',
      'IdiotBot' => '1/1',
      'NeuronC' => '1/1',
      'SimpleBot' => '1/1',
      'gonzoBot2' => '1/1',
      'viking5' => '1/1'
    },
    'viking5' => {
      'Go81' => '1/1',
      'IdiotBot' => '1/1',
      'NeuronC' => '1/1',
      'SimpleBot' => '1/1',
      'gonzoBot2' => '1/1',
      'tlsBotExp1' => '0/1'
    }
  },
  'time_zone' => 'GMT'
}
